import React, { useState, useEffect } from 'react'
import axios from 'axios'
import {
  Box,
  Typography,
  Grid,
  Paper,
  Avatar,
  Button,
  TextField,
  Modal,
  DialogActions,
} from '@mui/material'
import { useNavigate, useParams } from 'react-router-dom'
import { format } from 'date-fns'
import Axios from '../../../axios'
import { isAutheticated } from '../../../auth'
import MessageList from './MessageList'
import Swal from 'sweetalert2'
import ImgModal from './imgModal'

const KycDetails = () => {
  const { id } = useParams()
  const [openRejectModal, setOpenRejectModal] = useState(false)
  const [openApproveModal, setOpenApproveModal] = useState(false)
  const [rejectionReason, setRejectionReason] = useState('')
  const [selectedRowId, setSelectedRowId] = useState(null)
  const [retailerDetails, setRetailerDetails] = useState(null)
  const [openImageModal, setOpenImageModal] = useState(false)
  const [selectedImageUrl, setSelectedImageUrl] = useState('')
  const token = isAutheticated()

  const navigate = useNavigate()

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await Axios.get(`/api/kyc/get-single-kyc/${id}`, {
          headers: {
            'Access-Control-Allow-Origin': '*',
            Authorization: `Bearer ${token}`,
            'Content-Type': 'multipart/formdata',
          },
        })
        console.log(response.data)
        setRetailerDetails(response.data)
      } catch (error) {
        console.error('Error fetching data: ', error)
      }
    }

    fetchData()
  }, [id])

  const [msg, setMsg] = useState('')
  const handelSend = async () => {
    try {
      const resp = await Axios.patch(
        `/api/kyc/update/${id}`,
        {
          rejectionReason: msg,

          user: 'Principal Distributer', // Replace with actual user type
        },
        {
          headers: {
            Authorization: `Bearer ${token}`,
            'Content-Type': 'application/json',
          },
        },
      )
      setRetailerDetails(resp.data.kyc)
      setMsg('')
      Swal.fire('Success', 'Message sent', 'success')
    } catch (error) {
      console.error('Error sending message: ', error)
      Swal.fire('Error!', error.message, 'error')
    }
  }

  const handleModalClose = () => {
    setOpenRejectModal(false)
    setOpenApproveModal(false)
    setRejectionReason('')
  }

  const handleRejectionReasonChange = (event) => {
    setRejectionReason(event.target.value)
  }
  const formatDateWithoutComma = (date) => {
    const dateObj = new Date(date)
    const dateStr = dateObj.toDateString().split(' ')
    return `${dateStr[1]} ${dateStr[2]} ${dateStr[3]}`
  }

  const handleRejectConfirm = async () => {
    try {
      const res = await Axios.patch(
        `/api/kyc/update/${id}`,
        {
          status: 'reject',
          rejectionReason,

          user: 'Principal Distributer', // Replace with actual user type
        },
        {
          headers: {
            Authorization: `Bearer ${token}`,
            'Content-Type': 'application/json',
          },
        },
      )
      setRetailerDetails(res.data.kyc)
      Swal.fire('Success', 'Rejected', 'success')
      handleModalClose()
    } catch (error) {
      console.error('Error rejecting KYC: ', error)
      Swal.fire('Error!', error.message, 'error')
      handleModalClose()
    }
  }

  const handleApproveConfirm = async () => {
    try {
      const res = await Axios.patch(
        `/api/kyc/update/${id}`,
        {
          status: 'approved',
          // user: 'Principal Distributer', // Replace with actual user type
        },
        {
          headers: {
            Authorization: `Bearer ${token}`,
            'Content-Type': 'application/json',
          },
        },
      )
      setRetailerDetails(res.data.kyc)
      Swal.fire('Success', 'Approved', 'success')
      handleModalClose()
    } catch (error) {
      console.error('Error approving KYC: ', error)
      Swal.fire('Error!', error.message, 'error')
      handleModalClose()
    }
  }

  const formatAMPM = (date) => {
    var hours = new Date(date).getHours()
    var minutes = new Date(date).getMinutes()
    var ampm = hours >= 12 ? 'PM' : 'AM'
    hours = hours % 12
    hours = hours ? hours : 12 // the hour '0' should be '12'
    minutes = minutes < 10 ? '0' + minutes : minutes
    var strTime = hours + ':' + minutes + ' ' + ampm
    return strTime
  }

  const handleRejectClick = () => {
    setOpenRejectModal(true)
  }

  const handleApproveClick = () => {
    setOpenApproveModal(true)
  }

  const handleImageClick = (url) => {
    setSelectedImageUrl(url)
    console.log(selectedImageUrl)
    setOpenImageModal(true)
  }

  if (!retailerDetails) {
    return <Typography>Loading...</Typography>
  }

  return (
    <Box sx={{ p: 3 }}>
      <Box sx={{ display: 'flex', mb: '1rem' }}>
        <Typography variant="h4" flex={1} gutterBottom>
          Retailer Details
        </Typography>
        <Button
          onClick={() => navigate('/kyc')}
          color="primary"
          sx={{ padding: '0.5rem 1rem' }}
          variant="contained"
        >
          Back
        </Button>
      </Box>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h5" gutterBottom>
          Retailer Details
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <Typography>
              <strong>Trade Name:</strong> {retailerDetails.trade_name}
            </Typography>
            <Typography>
              <strong>Name:</strong> {retailerDetails.name}
            </Typography>
            <Typography>
              <strong>Address:</strong> {retailerDetails.address}
            </Typography>
            <Typography>
              <strong>Town/City:</strong> {retailerDetails.city}
            </Typography>
          </Grid>
          <Grid item xs={6}>
            <Typography>
              <strong>District:</strong> {retailerDetails.district}
            </Typography>
            <Typography>
              <strong>State:</strong> {retailerDetails.state}
            </Typography>
            <Typography>
              <strong>Pincode:</strong> {retailerDetails.pincode}
            </Typography>
            <Typography>
              <strong>Mobile Number:</strong> {retailerDetails.mobile_number}
            </Typography>
            <Typography>
              <strong>Mapped Principal Distributor:</strong>{' '}
              {retailerDetails.principal_distributer.name}
            </Typography>
          </Grid>
        </Grid>
      </Paper>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h6" gutterBottom>
          Documents
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <Typography>
              <strong>PAN Number:</strong> {retailerDetails.pan_number}
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.pan_img.url}
              sx={{ width: 100, height: 100, mb: 2 }}
              onClick={() => handleImageClick(retailerDetails.pan_img.url)}
            />
            <Typography>
              <strong>Aadhar Number:</strong> {retailerDetails.aadhar_number}
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.aadhar_img.url}
              sx={{ width: 100, height: 100, mb: 2 }}
              onClick={() => handleImageClick(retailerDetails.aadhar_img.url)}
            />
            <Typography>
              <strong>GST Number:</strong> {retailerDetails.gst_number}
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.gst_img.url}
              sx={{ width: 100, height: 100, mb: 2 }}
              onClick={() => handleImageClick(retailerDetails.gst_img.url)}
            />
          </Grid>
          <Grid item xs={6}>
            <Typography>
              <strong>Pesticide License:</strong>
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.pesticide_license_img.url}
              sx={{ width: 100, height: 100, mb: 2 }}
              onClick={() => handleImageClick(retailerDetails.pesticide_license_img.url)}
            />
            <Typography>
              <strong>Fertilizer License (optional):</strong>
            </Typography>
            {retailerDetails.fertilizer_license_img ? (
              <Avatar
                variant="square"
                src={retailerDetails.fertilizer_license_img.url}
                sx={{ width: 100, height: 100, mb: 2 }}
                onClick={() => handleImageClick(retailerDetails.fertilizer_license_img.url)}
              />
            ) : (
              <Typography>Img not available</Typography>
            )}
            <Typography>
              <strong>Selfie of Entrance Board:</strong>
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.selfie_entrance_img.url}
              sx={{ width: 100, height: 100, mb: 2 }}
              onClick={() => handleImageClick(retailerDetails.selfie_entrance_img.url)}
            />
          </Grid>
        </Grid>
      </Paper>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h6" gutterBottom>
          Sales Coordinators/Territory Manager Details
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <Typography>
              <strong>Designation:</strong>{' '}
              {retailerDetails.userType === 'SalesCoOrdinator'
                ? 'Sales Coordinator'
                : 'Territory Manager'}
            </Typography>
            <Typography>
              <strong>Name:</strong> {retailerDetails.addedBy.name}
            </Typography>
            <Typography>
              <strong>Employee ID:</strong> {retailerDetails.addedBy.uniqueId}
            </Typography>
          </Grid>
          <Grid item xs={6}>
            <Typography>
              <strong>Uploaded on:</strong>{' '}
              {/* {new Date(`${retailerDetails?.createdAt}`).toDateString()} */}
              {`${formatDateWithoutComma(retailerDetails?.createdAt)}`}
              <span> , {`${formatAMPM(retailerDetails?.createdAt)}`}</span>
            </Typography>
            <Typography>
              <strong>Resubmitted on:</strong>{' '}
              {/* {new Date(`${retailerDetails?.updatedAt}`).toDateString()} */}
              {`${formatDateWithoutComma(retailerDetails?.updatedAt)}`}
              <span> , {`${formatAMPM(retailerDetails?.createdAt)}`}</span>
            </Typography>
          </Grid>
        </Grid>
      </Paper>

      {retailerDetails.notes.length > 0 && retailerDetails.status === 'reject' && (
        <Paper sx={{ p: 2, mb: 3 }}>
          <Typography variant="h6" gutterBottom>
            Notes:
          </Typography>

          <MessageList messages={retailerDetails.notes} />

          <TextField
            fullWidth
            multiline
            rows={4}
            value={msg}
            onChange={(e) => setMsg(e.target.value)}
            variant="outlined"
            label="send message"
          />
          <Button
            variant="contained"
            sx={{ textTransform: 'unset', mt: '2rem' }}
            onClick={() => handelSend()}
          >
            Send
          </Button>
        </Paper>
      )}
      {retailerDetails.status === 'new' && (
        <>
          <Modal
            open={openRejectModal}
            onClose={handleModalClose}
            aria-labelledby="modal-modal-title"
            aria-describedby="modal-modal-description"
          >
            <Box sx={{ ...modalStyle, width: 400 }}>
              <h2 id="modal-modal-title">Rejection Reason</h2>
              <TextField
                fullWidth
                multiline
                rows={4}
                value={rejectionReason}
                onChange={handleRejectionReasonChange}
                variant="outlined"
                label="Enter rejection reason"
              />
              <DialogActions>
                <Button onClick={handleModalClose} sx={{ textTransform: 'unset' }} color="primary">
                  Cancel
                </Button>
                <Button
                  onClick={handleRejectConfirm}
                  sx={{ textTransform: 'unset' }}
                  color="error"
                  variant="contained"
                >
                  Confirm
                </Button>
              </DialogActions>
            </Box>
          </Modal>

          <Modal
            open={openApproveModal}
            onClose={handleModalClose}
            aria-labelledby="modal-modal-title"
            aria-describedby="modal-modal-description"
          >
            <Box sx={{ ...modalStyle, width: 400 }}>
              <h2 id="modal-modal-title">Approval Confirmation</h2>
              <Typography id="modal-modal-description" sx={{ mt: 2 }}>
                Are you sure you want to approve this KYC?
              </Typography>
              <DialogActions>
                <Button onClick={handleModalClose} sx={{ textTransform: 'unset' }} color="primary">
                  Cancel
                </Button>
                <Button
                  onClick={handleApproveConfirm}
                  sx={{ textTransform: 'unset' }}
                  color="success"
                  variant="contained"
                >
                  Confirm
                </Button>
              </DialogActions>
            </Box>
          </Modal>

          <Paper sx={{ p: 2, mb: 3 }}>
            <Button
              sx={{ mr: '1rem', textTransform: 'unset' }}
              color="success"
              variant="contained"
              onClick={handleApproveClick}
            >
              Approve
            </Button>
            <Button
              sx={{ mr: '1rem', textTransform: 'unset' }}
              color="error"
              variant="contained"
              onClick={handleRejectClick}
            >
              Reject
            </Button>
          </Paper>
        </>
      )}
      <ImgModal
        open={openImageModal}
        handleClose={() => setOpenImageModal(false)}
        imageUrl={selectedImageUrl}
      />
    </Box>
  )
}

const modalStyle = {
  position: 'absolute',
  top: '50%',
  left: '50%',
  transform: 'translate(-50%, -50%)',
  bgcolor: 'background.paper',
  boxShadow: 24,
  p: 4,
}

export default KycDetails
