import {
  Box,
  Button,
  FormControl,
  FormControlLabel,
  Grid,
  InputLabel,
  MenuItem,
  Radio,
  RadioGroup,
  Select,
  Typography,
  FormHelperText,
} from '@mui/material'
import React, { useState } from 'react'
import Axios from '../../../axios'
import { isAutheticated } from '../../../auth'

const AddressAndPayment = ({
  billTo,
  setBillTo,
  shipTo,
  setShipTo,
  paymentMode,
  setPaymentMode,
  handleTabChange,
  address,
}) => {
  const [billToError, setBillToError] = useState(false)
  const [shipToError, setShipToError] = useState(false)

  const [paymentModeError, setPaymentModeError] = useState(false)

  const handleReviewOrderClick = (e) => {
    let isValid = true

    // Check if Bill Address is filled
    if (billTo === '') {
      setBillToError(true)
      isValid = false
    } else {
      setBillToError(false)
    }

    // Check if Ship Address is filled
    if (shipTo === '') {
      setShipToError(true)
      isValid = false
    } else {
      setShipToError(false)
    }

    // Check if Payment Mode is selected
    if (paymentMode === '') {
      setPaymentModeError(true)
      isValid = false
    } else {
      setPaymentModeError(false)
    }

    // If all fields are valid, move to the next tab
    if (isValid) {
      handleTabChange(e, 2)
    }
  }
  const formatAddress = (address) => {
    const { street, city, state, postalCode } = address
    return `${street}, ${city}, ${state} - ${postalCode}`
  }

  return (
    <div>
      <Box sx={{ my: '2rem', background: '#fff', padding: '1rem', borderRadius: '0.8rem' }}>
        <Typography variant="h4" textAlign={'center'} marginBottom={2}>
          Select Address and Payment Mode
        </Typography>
        <Grid container spacing={3}>
          <Grid item sm={6} md={6} lg={6}>
            <Typography sx={{ mb: '0.5rem' }}>Bill Address</Typography>
            <FormControl required fullWidth error={billToError}>
              <InputLabel id="bill-address-label">Bill Address</InputLabel>
              <Select
                labelId="bill-address-label"
                id="bill-address-select"
                required
                value={billTo}
                label="Bill Address"
                onChange={(e) => setBillTo(e.target.value)}
              >
                {address &&
                  address.map((address) => (
                    <MenuItem key={address._id} value={formatAddress(address)}>
                      {formatAddress(address)}
                    </MenuItem>
                  ))}
              </Select>
              {billToError && <FormHelperText>Bill Address is required</FormHelperText>}
            </FormControl>
          </Grid>
          <Grid item sm={6} md={6} lg={6}>
            <Typography sx={{ mb: '0.5rem' }}>Ship Address</Typography>
            <FormControl required fullWidth error={shipToError}>
              <InputLabel id="ship-address-label">Ship Address</InputLabel>
              <Select
                labelId="ship-address-label"
                id="ship-address-select"
                value={shipTo}
                label="Ship Address"
                onChange={(e) => setShipTo(e.target.value)}
              >
                {address &&
                  address.map((address) => (
                    <MenuItem key={address._id} value={formatAddress(address)}>
                      {formatAddress(address)}
                    </MenuItem>
                  ))}
              </Select>

              {shipToError && <FormHelperText>Ship Address is required</FormHelperText>}
            </FormControl>
          </Grid>
          {billTo !== '' && (
            <Grid item sm={6} md={6} lg={6}>
              <Typography variant="h5" sx={{ mb: '0.5rem' }}>
                Selected Bill Address
              </Typography>
              <Typography sx={{ mb: '0.5rem' }}>{billTo}</Typography>
            </Grid>
          )}
          {shipTo !== '' && (
            <Grid item sm={6} md={6} lg={6}>
              <Typography variant="h5" sx={{ mb: '0.5rem' }}>
                Selected Ship to Address
              </Typography>
              <Typography sx={{ mb: '0.5rem' }}>{shipTo}</Typography>
            </Grid>
          )}
          <Grid item sm={12} md={12} lg={12}>
            <Typography>Payment Mode</Typography>
            <FormControl component="fieldset" error={paymentModeError}>
              <RadioGroup value={paymentMode} onChange={(e) => setPaymentMode(e.target.value)}>
                <FormControlLabel
                  value="online-transfer"
                  control={<Radio />}
                  label="Online Transfer"
                />
                <FormControlLabel value="cheque" control={<Radio />} label="Cheque" />
                <FormControlLabel value="credit" control={<Radio />} label="Credit" />
              </RadioGroup>
              {paymentModeError && <FormHelperText>Payment Mode is required</FormHelperText>}
            </FormControl>
          </Grid>
        </Grid>
        <Box sx={{ display: 'flex', justifyContent: 'center', my: 4 }}>
          <Button
            variant="contained"
            size="large"
            color="primary"
            onClick={handleReviewOrderClick}
            sx={{ width: '200px' }}
          >
            View Order
          </Button>
        </Box>
      </Box>
    </div>
  )
}

export default AddressAndPayment
