import React, { useEffect, useState } from 'react'
import { Box, Button, colors, Container, IconButton, Tab, Tabs, Typography } from '@mui/material'
import CheckIcon from '@mui/icons-material/Check'
// import ShoppingCart from '../../Components/ShoppingCart'
// import CheckoutDetails from '../../Components/CheckoutDetails'
// import OrderComplete from '../../Components/OrderComplete'
import PropTypes from 'prop-types'
import Checkout from './addressAndPayment'
import ShopingCart from './shopingCart'
import OrderComplete from './orderConfirmation'
import AddressAndPayment from './addressAndPayment'
import Swal from 'sweetalert2'
import ReviewOrder from './reviewOrder'
import OrderConfirmation from './orderConfirmation'
import { useDispatch, useSelector } from 'react-redux'
import {
  clearCart,
  loadCart,
  selectCartItemCount,
  selectCartItems,
  selectCartSubtotal,
} from '../../../redux-store/CartStore/ducs'
import { isAutheticated } from '../../../auth'
import Axios from '../../../axios'

const TabItem = ({ label, active, complete, onClick, reference, stepNumber }) => (
  <Box
    ref={reference}
    onClick={onClick}
    sx={{
      minWidth: '256px',
      display: 'flex',
      alignItems: 'center',
      pb: '1rem',
      cursor: 'pointer',
      borderBottom: complete ? '2px solid #45B26B' : active ? '2px solid black' : '',
    }}
  >
    <IconButton
      sx={{
        background: complete ? '#45B26B' : active ? '#000' : '#B1B5C3',
        marginRight: '1rem',
      }}
    >
      {complete ? (
        <CheckIcon sx={{ color: 'white' }} />
      ) : (
        <Typography
          color={active ? 'white' : complete ? '#45B26B' : '#FCFCFD'}
          width={30}
          height={30}
          borderRadius={'50%'}
        >
          {stepNumber}
        </Typography>
      )}
    </IconButton>
    <Typography
      sx={{
        fontFamily: 'inter',
        fontSize: '1rem',
        fontWeight: 'bold',
        color: complete ? '#45B26B' : active ? 'black' : '#B1B5C3',
      }}
    >
      {label}
    </Typography>
  </Box>
)

TabItem.propTypes = {
  label: PropTypes.string.isRequired,
  active: PropTypes.bool.isRequired,
  complete: PropTypes.bool.isRequired,
  onClick: PropTypes.func.isRequired,
  reference: PropTypes.object.isRequired,
  stepNumber: PropTypes.number.isRequired,
}
const styles = {
  tab: {
    backgroundColor: '#FFFFFF',
    color: 'black',
    padding: '0px 25px',
    textAlign: 'center',
    textTransform: 'none',
    textDecoration: 'none',
    minWidth: 50,
    '&.Mui-selected': {
      backgroundColor: '#007FFF',
      border: 'none',
      color: 'white',
      textAlign: 'center',
      textDecoration: 'none',
    },
  },
  tabs: {
    // maxWidth: 355,
    borderRadius: 20,
    maxHeight: 50,
    '&.MuiTabs-root': {
      minHeight: 0,
    },
  },
}

const Cart = () => {
  const [shipTo, setShipTo] = useState('')
  const [billTo, setBillTo] = useState('')
  const dispatch = useDispatch()
  const [paymentMode, setPaymentMode] = useState('')
  const cartItems = useSelector(selectCartItems)

  const [address, setAddress] = useState([])
  const token = isAutheticated()
  const [value, setValue] = useState(0)

  const getAddress = async () => {
    try {
      const res = await Axios.get('/api/rd/shipping/address/', {
        headers: {
          'Access-Control-Allow-Origin': '*',
          Authorization: `Bearer ${token}`,
          'Content-Type': 'application/json',
        },
      })
      console.log(res)
      setAddress(res?.data?.UserShippingAddress)
    } catch (error) {
      console.log(error)
    }
  }
  useEffect(() => {
    getAddress()
  }, [])
  const handleTabChange = (event, newValue) => {
    if (value === 3 && newValue !== 3) {
      setPaymentMode('')
      setBillTo('')
      setShipTo('')
      dispatch(clearCart())
    }
    if (newValue === 1 && cartItems.length === 0) {
      Swal.fire('Cart is emplty ,can not move to next screen pls add items to cart ')
      return
    }

    if (newValue === 2 && (shipTo === '' || billTo === '' || paymentMode === '')) {
      Swal.fire('Fill all the details ,can not move to next screen ')
      return
    }
    if (newValue === 3 && (shipTo === '' || billTo === '' || paymentMode === '')) {
      Swal.fire('Fill all the details ,can not move to next screen ')
      return
    }

    setValue(newValue)
  }
  // const handleAddressAndOrderClick = () => {
  //   if (cartItems.length === 0) {
  //     Swal.fire('Cart is emplty can not move to next screen pls add items to cart ')
  //     return
  //   }
  //   setValue(1)
  // }
  const [orderId, setOrderId] = useState(null)
  // const [cartItem, setCartItem] = useState([
  //   {
  //     product: {
  //       _id: '1',
  //       name: 'Product 1',
  //       image: [
  //         {
  //           url: 'https://images.pexels.com/photos/341523/pexels-photo-341523.jpeg?auto=compress&cs=tinysrgb&w=600',
  //         },
  //       ],
  //       variant: { price: 100, gst_Id: { tax: 5 } },
  //       hsn: '1234',
  //     },
  //     quantity: 2,
  //     subtotal: 200,
  //   },
  //   {
  //     product: {
  //       _id: '2',
  //       name: 'Product 2',
  //       image: [
  //         {
  //           url: 'https://images.pexels.com/photos/341523/pexels-photo-341523.jpeg?auto=compress&cs=tinysrgb&w=600',
  //         },
  //       ],
  //       variant: { price: 150, gst_Id: { tax: 5 } },
  //       hsn: '5678',
  //     },
  //     quantity: 1,
  //     subtotal: 150,
  //   },
  // ])

  return (
    <Container>
      <Tabs
        value={value}
        indicatorColor="primary"
        textColor="primary"
        onChange={handleTabChange}
        TabIndicatorProps={{
          style: {
            backgroundColor: 'white',
            display: 'none',
          },
        }}
        sx={styles.tabs}
      >
        <Tab label="Cart " value={0} sx={styles.tab} />
        <Tab label="Address and Payment Mode" value={1} sx={styles.tab} />
        <Tab label="Review Order" value={2} sx={styles.tab} />
        <Tab label="Order Confirmation" value={3} sx={styles.tab} />
      </Tabs>

      {value === 0 &&
        (cartItems.length === 0 ? (
          <Typography sx={{ m: '2rem ', background: '#FFF', padding: '1rem' }}>
            No items available. Please add items to the cart.
          </Typography>
        ) : (
          <Box>
            <ShopingCart cartItems={cartItems} handleTabChange={handleTabChange} />
          </Box>
        ))}

      {value === 1 && (
        <Box>
          <AddressAndPayment
            billTo={billTo}
            setBillTo={setBillTo}
            shipTo={shipTo}
            setShipTo={setShipTo}
            paymentMode={paymentMode}
            setPaymentMode={setPaymentMode}
            handleTabChange={handleTabChange}
            address={address}
          />
        </Box>
      )}
      {value === 2 && (
        <Box>
          <ReviewOrder
            billTo={billTo}
            shipTo={shipTo}
            paymentMode={paymentMode}
            orderId={orderId}
            setOrderId={setOrderId}
            cartItem={cartItems}
            handleTabChange={handleTabChange}
          />
        </Box>
      )}
      {value === 3 && (
        <Box>
          <OrderConfirmation
            billTo={billTo}
            shipTo={shipTo}
            paymentMode={paymentMode}
            orderId={orderId}
            cartItem={cartItems}
          />
        </Box>
      )}
    </Container>
  )
}

export default Cart
