import React from 'react'
import {
  Box,
  Container,
  Grid,
  Paper,
  Typography,
  Button,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  useMediaQuery,
} from '@mui/material'
import ClearIcon from '@mui/icons-material/Clear'
import { useDispatch, useSelector } from 'react-redux'
import {
  selectCartItems,
  selectCartSubtotal,
  increaseCount,
  decreaseCount,
  removeFromCart,
  selectCartItemCount,
} from '../../../redux-store/CartStore/ducs' // Adjust this path as per your project structure

const ShoppingCart = ({ handleTabChange }) => {
  const matches = useMediaQuery('(min-width:1200px)')
  const dispatch = useDispatch()

  // Fetching cart items and subtotal from the Redux store
  const cartItems = useSelector(selectCartItems)
  const subtotal = useSelector(selectCartSubtotal)
  console.log(cartItems)
  // Calculate total GST for the entire cart
  const totalGST = cartItems.reduce((acc, item) => {
    // console.log(item)
    const gstAmount = (item.price * item.GST) / 100
    return acc + gstAmount * item.count
  }, 0)

  const handleDecrease = (productId) => {
    dispatch(decreaseCount(productId))
  }

  const handleIncrease = (productId) => {
    dispatch(increaseCount(productId))
  }

  const removeCartItemHandler = (productId) => {
    dispatch(removeFromCart(productId))
  }

  return (
    <Box>
      <Container>
        <Box my={8}>
          <Grid container spacing={5}>
            <Grid item xs={12}>
              <Box>
                <TableContainer
                  component={Paper}
                  elevation={0}
                  sx={{ borderBottom: '1.5px solid #CFCFD5', borderRadius: 0 }}
                >
                  <Table sx={{ minWidth: 650 }} size="large">
                    <TableHead>
                      <TableRow>
                        <TableCell sx={{ fontWeight: 'bold' }}>Product</TableCell>
                        <TableCell sx={{ fontWeight: 'bold' }}>SKU</TableCell>
                        <TableCell sx={{ fontWeight: 'bold' }}>Quantity</TableCell>
                        <TableCell sx={{ fontWeight: 'bold' }}>Price</TableCell>
                        <TableCell sx={{ fontWeight: 'bold' }}>GST</TableCell>
                        <TableCell sx={{ fontWeight: 'bold' }}>Subtotal</TableCell>
                      </TableRow>
                    </TableHead>
                    <TableBody>
                      {cartItems.map((row, index) => {
                        const gstAmount = (row.price * row.GST) / 100

                        return (
                          <TableRow
                            key={index}
                            sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
                          >
                            <TableCell>
                              <Box sx={{ display: 'flex' }}>
                                {/* <img
                                  src={row.product.image[0].url}
                                  alt={row.product.name}
                                  style={{ width: '100px', height: '70px', marginRight: '1rem' }}
                                /> */}
                                <Box>
                                  <Typography fontWeight={600}>{row.name}</Typography>
                                  <Box
                                    onClick={() => removeCartItemHandler(row._id)}
                                    sx={{
                                      display: 'flex',
                                      alignItems: 'center',
                                      cursor: 'pointer',
                                      color: '#6C7275',
                                      marginTop: '0.5rem',
                                    }}
                                  >
                                    <ClearIcon fontSize="small" />
                                    <Typography>Remove</Typography>
                                  </Box>
                                </Box>
                              </Box>
                            </TableCell>
                            <TableCell>{row.SKU}</TableCell>
                            <TableCell>
                              <Box
                                sx={{
                                  display: 'flex',
                                  alignItems: 'center',
                                  border: '1px solid #6C7275',
                                  borderRadius: '4px',
                                  width: '80px',
                                  justifyContent: 'space-between',
                                }}
                              >
                                <Typography
                                  onClick={() => handleDecrease(row._id)}
                                  sx={{ cursor: 'pointer', padding: '0.5rem' }}
                                >
                                  -
                                </Typography>
                                <Typography>{row.count}</Typography>
                                <Typography
                                  onClick={() => handleIncrease(row._id)}
                                  sx={{ cursor: 'pointer', padding: '0.5rem' }}
                                >
                                  +
                                </Typography>
                              </Box>
                            </TableCell>
                            <TableCell>₹{row.price}</TableCell>
                            <TableCell>₹{gstAmount.toFixed(2)}</TableCell>
                            <TableCell>₹{row.price * row.count}</TableCell>
                          </TableRow>
                        )
                      })}
                      <TableRow>
                        <TableCell colSpan={5} />
                        <TableCell>
                          Subtotal:<strong> ₹ {subtotal}</strong>
                        </TableCell>
                      </TableRow>
                      <TableRow>
                        <TableCell colSpan={5} />
                        <TableCell>
                          Total GST:<strong> ₹ {totalGST.toFixed(2)} </strong>
                        </TableCell>
                      </TableRow>

                      <TableRow>
                        <TableCell colSpan={5} />

                        <TableCell>
                          Grand total: <strong> ₹ {subtotal + totalGST}</strong>
                        </TableCell>
                      </TableRow>
                    </TableBody>
                  </Table>
                </TableContainer>
              </Box>
            </Grid>
          </Grid>
        </Box>
      </Container>

      <Box sx={{ display: 'flex', justifyContent: 'center', my: 4 }}>
        <Button
          variant="contained"
          size="large"
          color="primary"
          onClick={(e) => handleTabChange(e, 1)}
          sx={{
            width: '200px',
          }}
        >
          Address and payment mode
        </Button>
      </Box>
    </Box>
  )
}

export default ShoppingCart
